@@ -93,7 +93,7 @@ class BioDataReader(object):
     >>> print br.labels
     [ 1. -1.  1.  1.]
     >>>
-    
+
     """
 
     def __init__(self, data_file, labels_file,
@@ -158,7 +158,7 @@ class BioDataReader(object):
 
         try:
             unique_labels, _, _ = _check_unique_labels(labels)
-            self.labels = np.empty_like(labels, dtype=float)
+            self.labels = np.empty(labels.shape, dtype=float)
 
             if not positive_label is None:
                 positive_label = str(positive_label)
